;; Generated package description from consult.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "consult" "2.4" "Consulting completing-read" '((emacs "28.1") (compat "30")) :commit "e57fbb65584f3160f98a2569b1674c8065ec8df8" :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("matching" "files" "completion") :url "https://github.com/minad/consult")
